@@ -1,4 +1,5 @@
 UFA_profile_visualizer <- function(PARAM_SA) {
+  ##
   input_path_hrms <- PARAM_SA[which(PARAM_SA[, 1] == 'PARAM0010'), 2]
   if (tolower(PARAM_SA[which(PARAM_SA[, 1] == 'PARAM0011'), 2]) == "all") {
     file_name_hrms <- dir(path = input_path_hrms)
@@ -18,7 +19,7 @@ UFA_profile_visualizer <- function(PARAM_SA) {
   file_names_peaklist_hrms <- file_name_hrms %in% file_names_peaklist_hrms2
   L_PL <- length(which(file_names_peaklist_hrms == TRUE))
   if (length(file_name_hrms) != L_PL) {
-    stop(UFA_logRecorder("Error!!! peaklist files are not available for the entire selected HRMS files!"))
+    stop(IPA_logRecorder("Error!!! peaklist files are not available for the entire selected HRMS files!"))
   }
   ##
   output_path <- PARAM_SA[which(PARAM_SA[, 1] == 'PARAM0014'), 2]
@@ -30,9 +31,9 @@ UFA_profile_visualizer <- function(PARAM_SA) {
   output_path_spectra <- paste0(output_path, "/UFA_spectra/")
   if (!dir.exists(output_path_spectra)) {
     dir.create(output_path_spectra, recursive = TRUE)
-    UFA_logRecorder("Created UFA_spectra directory!")
+    IPA_logRecorder("Created UFA_spectra directory!")
   }
-  UFA_logRecorder("UFA_spectra comparison plots with theoretical isotopic profiles are stored in the `UFA_spectra` folder!")
+  IPA_logRecorder("UFA_spectra comparison plots with theoretical isotopic profiles are stored in the `UFA_spectra` folder!")
   opendir(output_path_spectra)
   ##
   molecular_formula <- eval(parse(text = paste0("c(", PARAM_SA[which(PARAM_SA[, 1] == 'SA0001'), 2], ")")))
@@ -44,9 +45,12 @@ UFA_profile_visualizer <- function(PARAM_SA) {
   UFA_IP_memeory_variables <- eval(parse(text = paste0("c(", PARAM_SA[which(PARAM_SA[, 1] == "SA0007"), 2], ")")))
   mass_accuracy <- as.numeric(PARAM_SA[which(PARAM_SA[, 1] == 'SA0008'), 2])
   number_processing_threads <- as.numeric(PARAM_SA[which(PARAM_SA[, 1] == 'SA0009'), 2])
-  exportSpectra <- if (tolower(PARAM_SA[which(PARAM_SA[, 1] == 'SA0010'), 2]) == "yes") {TRUE} else {FALSE}
-  exportedAnnotatedSpectraTable <- if (tolower(PARAM_SA[which(PARAM_SA[, 1] == 'SA0011'), 2]) == "yes") {TRUE} else {FALSE}
-  if (exportSpectra == TRUE | exportedAnnotatedSpectraTable == TRUE) {
+  exportSpectraCheck <- if (tolower(PARAM_SA[which(PARAM_SA[, 1] == 'SA0010'), 2]) == "yes") {TRUE} else {FALSE}
+  exportedAnnotatedSpectraTableCheck <- if (tolower(PARAM_SA[which(PARAM_SA[, 1] == 'SA0011'), 2]) == "yes") {TRUE} else {FALSE}
+  ##
+  namesAnnotation <- c("PeakID", "ID_IonFormula", "sizeIP", "IonFormula", "m/z theoretical", "m/z peaklist", "Mass accuracy (Da)", "RetentionTime(min)", "PeakHeight", "NEME (mDa)", "PCS (per-mille)", "R13C peaklist (%)", "R13C theoretical (%)", "NDCS @ 80%", "RCS (%) @ 80%")
+  ##
+  if (exportSpectraCheck == TRUE | exportedAnnotatedSpectraTableCheck == TRUE) {
     ##
     EL <- element_sorter()
     Elements <- EL[["Elements"]]
@@ -122,7 +126,7 @@ UFA_profile_visualizer <- function(PARAM_SA) {
       c(IPP[x_100, 1], r13c_ip, x_100, L_IPP)
     }
     ##
-    SpectraAnalysis_call <- function (i_pl) {
+    SpectraAnalysis_call <- function(i_pl) {
       peaklist <- IDSL.IPA::loadRdata(paste0(input_path_pl, "/peaklist_", file_name_hrms[i_pl], ".Rdata"))
       ##
       outputer <- IDSL.IPA::IPA_MSdeconvoluter(input_path_hrms, file_name_hrms[i_pl])
@@ -185,90 +189,116 @@ UFA_profile_visualizer <- function(PARAM_SA) {
                           round(R13C_IP, 2),
                           NDCS,
                           round(RCS, 2))
-          Annotation <- data.frame(Annotation)
-          rownames(Annotation) <- c("PeakID", "ID_IonFormula", "sizeIP", "IonFormula", "m/z theoretical", "m/z peaklist", "Mass accuracy (Da)", "RetentionTime(min)", "PeakHeight", "NEME (mDa)", "PCS (per-mille)", "R13C peaklist (%)", "R13C theoretical (%)", "NDCS @ 80%", "RCS (%) @ 80%")
-          if (exportSpectra == TRUE) {
-            exp_spectra <- data.frame(matrix(cbind(Ave_MW_exp, sum_INT_exp/sum_INT_exp[x_100]*100), ncol = 2))
-            colnames(exp_spectra) <- c("mz", "int")
-            theo_spectra <- data.frame(IsotopicProfile)
-            colnames(theo_spectra) <- c("mz", "int")
-            lablel_spectra <- data.frame(cbind(round(exp_spectra[, 1], 5), sapply(1:size_IP, function(la_i) {max(c(exp_spectra[la_i, 2], theo_spectra[la_i, 2])) + 2})))
-            max_int <- 1.15*max(c(theo_spectra[, 2], exp_spectra[, 2]))
-            colnames(lablel_spectra) <- c("mz", "int")
-            spectra_figure <- ggplot(data=exp_spectra, aes(x=mz, y=int)) +
-              geom_segment(data=theo_spectra, aes(x=mz, xend=mz, y=0, yend=int, col = "Theoretical"), size = 6) +
-              geom_segment(data=exp_spectra, aes(x=mz, xend=mz, y=0, yend=int, col = "Experimental"), size = 2) +
-              scale_color_discrete(name = NULL) +
-              xlab("m/z") + ylab("Intensity (%)") +
-              scale_x_continuous(limits = c(theo_spectra[1, 1]-1, theo_spectra[size_IP, 1]+1), expand = c(0, 0)) +
-              scale_y_continuous(limits = c(0, max_int), expand = c(0, 0)) +
-              geom_text(data=lablel_spectra, aes(x=mz, y=int, label = round(mz, 5)), cex = 5) +
-              annotate("text", x = (theo_spectra[1, 1]+theo_spectra[size_IP, 1])/2, y = max_int/1.05, label = paste0("[", molecular_formula_hill[j], "]", MS_polarity), size = 5) +
-              labs(title = file_name_hrms[i_pl]) +
-              theme_bw() + theme(legend.position = c(0.83, 0.95), legend.margin = margin(0, 0, 0, 0), panel.grid.major = element_blank(), panel.grid.minor = element_blank(),
-                                 text = element_text(size = 24), plot.title = element_text(size = 14))
-            my_table <- tableGrob(Annotation, theme = ttheme_default()) ## create insert table
-            spectra_figure <- grid.arrange(spectra_figure, my_table, ncol = 2) ## final result
-            ggsave(filename=paste0("/UFA_spectra_", file_name_hrms[i_pl], "_", j, "_", molecular_formula_hill[j], "_",round(RT_target[j], 2), ".png"),
-                   plot = spectra_figure,
-                   device = "png",
-                   path = output_path_spectra,
-                   scale = 1,
-                   width = 16,
-                   height = 8,
-                   units = "in",
-                   dpi = 100)
+          ######################################################################
+          if (exportSpectraCheck) {
+            ##
+            annotationLabel <- do.call(c, lapply(1:15, function(k) {paste0(namesAnnotation[k], " = ", Annotation[k])}))
+            exp_spectra <- cbind(Ave_MW_exp, sum_INT_exp/sum_INT_exp[x_100]*100)
+            lablel_spectra <- data.frame(cbind(round(exp_spectra[, 1], 5), sapply(1:size_IP, function(la_i) {max(c(exp_spectra[la_i, 2], IsotopicProfile[la_i, 2])) + 3.5})))
+            ##
+            spectraFilename <- paste0(output_path_spectra, "/UFA_spectra_", file_name_hrms[i_pl], "_", j, "_", molecular_formula_hill[j], "_", round(RT_target[j], 2), ".png")
+            png(spectraFilename, width = 20, height = 10, units = "in", res = 100)
+            ##
+            layout(matrix(c(1, 2), ncol = 2), widths = c(2, 1))
+            ##
+            plot(IsotopicProfile[, 1], IsotopicProfile[, 2], type = "h", xlim = c((min(IsotopicProfile[, 1]) - 1), (max(IsotopicProfile[, 1]) + 1)), ylim = c(0, 115),
+                 lwd = 16, lend = 2, col = "blue", xlab = "", ylab = "", yaxt = "n", yaxs = "i")
+            ##
+            lines(exp_spectra[, 1], exp_spectra[, 2], type = "h", lwd = 4, lend = 2, col = "red")
+            text(x = lablel_spectra[, 1], y = lablel_spectra[, 2], cex = 1.25, label = lablel_spectra[, 1])
+            legend(x = "topright", legend = c("Theoretical", "Experimental"),
+                   col = c("blue", "red"),
+                   lwd = c(8, 4),
+                   cex = 1.5, bty = "n", seg.len = 1, x.intersp = 0.5, y.intersp = 1)
+            mtext(file_name_hrms[i_pl], side = 3, adj = 0, line = 0.25, cex = 1.4)
+            mtext("m/z", side = 1, adj = 0.5, line = 2, cex = 1.35)
+            mtext("Intensity (%)", side = 2, adj = 0.5, line = 0.25, cex = 1.35)
+            text(x = (IsotopicProfile[1, 1] + IsotopicProfile[size_IP, 1])/2, y = 110, cex = 1.4, label = paste0("[", molecular_formula_hill[j], "]", MS_polarity))
+            ##
+            plot.new()
+            legend(x = "center", legend = annotationLabel,
+                   cex = 1.6, bty = "n", x.intersp = 0.05, y.intersp = 1.3, seg.len = 0)
+            ##
+            dev.off()
+            ####################################################################
           }
-          Annotation <- t(rbind(file_name_hrms[i_pl], Annotation))
+          Annotation <- c(file_name_hrms[i_pl], Annotation)
         }
         Annotation
       }))
       mzList.m
     }
     ##
-    osType <- Sys.info()[['sysname']]
-    if (osType == "Windows") {
-      clust <- makeCluster(number_processing_threads)
-      registerDoParallel(clust)
+    if (number_processing_threads == 1) {
       ##
-      IsotopicProfile_DataBase <- foreach(counter = 1:L_MoleFormVecMat, .verbose = FALSE) %dopar% {
+      IsotopicProfile_DataBase <- lapply(1:L_MoleFormVecMat, function (counter) {
         IP_calculator(counter)
-      }
-      ip_db_mat <- foreach(counter = 1:L_MoleFormVecMat, .combine = "rbind", .verbose = FALSE) %dopar% {
+      })
+      ##
+      ip_db_mat <- do.call(rbind, lapply(1:L_MoleFormVecMat, function (counter) {
         ip_db_function(counter)
-      }
+      }))
+      ip_db_mat <- matrix(ip_db_mat, ncol = 4)
       ##
       mz_DataBase <- ip_db_mat[, 1]
       R13C_DataBase <- ip_db_mat[, 2]
       MAIso_IsotopicProfile_DataBase <- ip_db_mat[, 3]
       SizeIP_IsotopicProfile_DataBase <- ip_db_mat[, 4]
       ##
-      AnnotatedSpectraTable <- foreach(counter = 1:L_PL, .combine = "rbind", .verbose = FALSE) %dopar% {
+      AnnotatedSpectraTable <- do.call(rbind, lapply(1:L_PL, function (counter) {
         SpectraAnalysis_call(counter)
+      }))
+    } else {
+      osType <- Sys.info()[['sysname']]
+      if (osType == "Linux") {
+        ##
+        IsotopicProfile_DataBase <- mclapply(1:L_MoleFormVecMat, function (counter) {
+          IP_calculator(counter)
+        }, mc.cores = number_processing_threads)
+        ##
+        ip_db_mat <- do.call(rbind, mclapply(1:L_MoleFormVecMat, function (counter) {
+          ip_db_function(counter)
+        }, mc.cores = number_processing_threads))
+        ip_db_mat <- matrix(ip_db_mat, ncol = 4)
+        ##
+        mz_DataBase <- ip_db_mat[, 1]
+        R13C_DataBase <- ip_db_mat[, 2]
+        MAIso_IsotopicProfile_DataBase <- ip_db_mat[, 3]
+        SizeIP_IsotopicProfile_DataBase <- ip_db_mat[, 4]
+        ##
+        AnnotatedSpectraTable <- do.call(rbind, mclapply(1:L_PL, function (counter) {
+          SpectraAnalysis_call(counter)
+        }, mc.cores = number_processing_threads))
+        ##
+        closeAllConnections()
+        ##
+      } else if (osType == "Windows") {
+        clust <- makeCluster(number_processing_threads)
+        registerDoParallel(clust)
+        ##
+        IsotopicProfile_DataBase <- foreach(counter = 1:L_MoleFormVecMat, .verbose = FALSE) %dopar% {
+          IP_calculator(counter)
+        }
+        ##
+        ip_db_mat <- foreach(counter = 1:L_MoleFormVecMat, .combine = 'rbind', .verbose = FALSE) %dopar% {
+          ip_db_function(counter)
+        }
+        ip_db_mat <- matrix(ip_db_mat, ncol = 4)
+        ##
+        mz_DataBase <- ip_db_mat[, 1]
+        R13C_DataBase <- ip_db_mat[, 2]
+        MAIso_IsotopicProfile_DataBase <- ip_db_mat[, 3]
+        SizeIP_IsotopicProfile_DataBase <- ip_db_mat[, 4]
+        ##
+        AnnotatedSpectraTable <- foreach(counter = 1:L_PL, .combine = 'rbind', .verbose = FALSE) %dopar% {
+          SpectraAnalysis_call(counter)
+        }
+        stopCluster(clust)
+        ##
       }
-      stopCluster(clust)
-      ##
-    } else if (osType == "Linux") {
-      ##
-      IsotopicProfile_DataBase <- mclapply(1:L_MoleFormVecMat, function (counter) {
-        IP_calculator(counter)
-      }, mc.cores = number_processing_threads)
-      ip_db_mat <- do.call(rbind, mclapply(1:L_MoleFormVecMat, function (counter) {
-        ip_db_function(counter)
-      }, mc.cores = number_processing_threads))
-      ##
-      mz_DataBase <- ip_db_mat[, 1]
-      R13C_DataBase <- ip_db_mat[, 2]
-      MAIso_IsotopicProfile_DataBase <- ip_db_mat[, 3]
-      SizeIP_IsotopicProfile_DataBase <- ip_db_mat[, 4]
-      ##
-      AnnotatedSpectraTable <- do.call(rbind, mclapply(1:L_PL, function (counter) {
-        SpectraAnalysis_call(counter)
-      }, mc.cores = number_processing_threads))
-      closeAllConnections()
     }
     ##
-    if (exportedAnnotatedSpectraTable == TRUE) {
+    if (exportedAnnotatedSpectraTableCheck) {
       AnnotatedSpectraTable <- data.frame(AnnotatedSpectraTable)
       rownames(AnnotatedSpectraTable) <- NULL
       colnames(AnnotatedSpectraTable) <- c("Filename", "PeakID", "ID_IonFormula", "sizeIP", "IonFormula", "m/z theoretical", "m/z peaklist", "Mass accuracy (Da)", "RetentionTime(min)", "PeakHeight", "NEME (mDa)", "PCS (per-mille)", "R13C peaklist (%)", "R13C theoretical (%)", "NDCS @ 80%", "RCS (%) @ 80%")
@@ -278,4 +308,4 @@ UFA_profile_visualizer <- function(PARAM_SA) {
       return()
     }
   }
-}
+}
\ No newline at end of file
