@@ -1,7 +1,7 @@
 aligned_molecular_formula_annotator <- function(PARAM) {
   ##
-  UFA_logRecorder(paste0(rep("", 100), collapse = "-"))
-  UFA_logRecorder("Initiated generating data for the aligned molecular formula annotated table!")
+  IPA_logRecorder(paste0(rep("", 100), collapse = "-"))
+  IPA_logRecorder("Initiated generating data for the aligned molecular formula annotated table!")
   ##
   number_processing_threads <- as.numeric(PARAM[which(PARAM[, 1] == "PARAM0009"), 2])
   input_path_peakXcol <- PARAM[which(PARAM[, 1] == 'PARAM0025'), 2]
@@ -15,45 +15,58 @@ aligned_molecular_formula_annotator <- function(PARAM) {
   mf_table_list <- dir(path = output_path_annotated_mf_tables, pattern = ".Rdata")
   ##
   ##############################################################################
+  ##############################################################################
   ##
   ColPL <- colnames(peakXcol)[3:L_samples2]
   ##
-  seqSample <- do.call(c, lapply(1:L_samples, function(i) {
+  seqXcolSample <- do.call(rbind, lapply(1:length(ColPL), function(i) {
     patternSampleName <- paste0("MolecularFormulaAnnotationTable_", ColPL[i], ".Rdata")
     ##
-    patternCheck <- grep(patternSampleName, mf_table_list)
-    if (length(patternCheck) > 0) {
-      i
+    xPatternCheck <- grep(patternSampleName, mf_table_list)
+    if (length(xPatternCheck) > 0) {
+      c(i, xPatternCheck)
+    } else {
+      c(i, 0)
     }
   }))
   ##
-  MissedPL <- setdiff((1:L_samples), seqSample)
+  MissedPL <- which(seqXcolSample[, 2] == 0)
   if (length(MissedPL) > 0) {
-    UFA_logRecorder("WARNING!!! The following MolecularFormulaAnnotationTables are not avialable:")
+    IPA_logRecorder("WARNING!!! The following MolecularFormulaAnnotationTables are not avialable:")
     for (i in MissedPL) {
-      UFA_logRecorder(ColPL[i])
+      IPA_logRecorder(ColPL[i])
     }
+    ##
+    seqXcolSample <- matrix(seqXcolSample[-MissedPL, ], ncol = 2)
   }
   ##
+  seqXcolSample <- matrix(seqXcolSample[order(seqXcolSample[, 2], decreasing = FALSE), ], ncol = 2)
+  orderSeqSample <- seqXcolSample[, 1]
+  seqSample <- seqXcolSample[, 2]
+  peakXcol <- peakXcol[, c(1, 2, (orderSeqSample + 2))]
+  ##
+  ##############################################################################
   ##############################################################################
   ##
   input_path_peak_property <- PARAM[which(PARAM[, 1] == 'PARAM0026'), 2]
   peak_property <- IDSL.IPA::loadRdata(input_path_peak_property)
   if (dim(peak_property)[1] != L_peaks | dim(peak_property)[2] != (L_samples2)) {
-    stop(UFA_logRecorder("Aligned peak property and peak indexed tables are not in the same size!"))
+    stop(IPA_logRecorder("Aligned peak property and peak indexed tables are not in the same size!"))
   }
-  peak_property <- peak_property[, c(1, 2, (seqSample + 2))]
+  peak_property <- peak_property[, c(1, 2, (orderSeqSample + 2))]
   ##
   maxRankSample <- as.numeric(PARAM[which(PARAM[, 1] == 'PARAM0027'), 2])
   Ncandidate <- as.numeric(PARAM[which(PARAM[, 1] == 'PARAM0028'), 2])
   ##
-  adjustFreqRankCheck <- ifelse((tolower(PARAM[which(PARAM[, 1] == 'PARAM0029'), 2]) == "yes"), TRUE, FALSE)
+  adjustFreqRankCheck <- if (tolower(PARAM[which(PARAM[, 1] == 'PARAM0029'), 2]) == "yes") {TRUE} else {FALSE}
+  ##
+  ##############################################################################
   ##
   call_MF_Zcol <- function(i) {
     peak_table_id <- peakXcol[, (i + 2)]
     MolecularFormulaAnnotationTable <- IDSL.IPA::loadRdata(paste0(output_path_annotated_mf_tables, "/", mf_table_list[i]))
     matched_peak_ids <- as.numeric(MolecularFormulaAnnotationTable[, 1])
-    x_peak_ids <- which(peak_table_id %in% unique(matched_peak_ids) == TRUE)
+    x_peak_ids <- which(peak_table_id %in% unique(matched_peak_ids))
     ##
     if (length(x_peak_ids) > 0) {
       matchedMolecularFormulas <- MolecularFormulaAnnotationTable$IonFormula
@@ -67,8 +80,12 @@ aligned_molecular_formula_annotator <- function(PARAM) {
     }
   }
   ##
+  ##############################################################################
+  ##
+  repNA00Ncandidate <- rep(c(NA, 0, 0), Ncandidate)
+  ##
   call_calculating_median_ranks <- function(i) {
-    molecularFormulaFreqRank <- rep(c(NA, 0, 0), Ncandidate)
+    molecularFormulaFreqRank <- repNA00Ncandidate
     ##
     if (xZcol[i, 1] != 0) {
       rankMolecularFormula <- MF_Zcol[xZcol[i, 1]:xZcol[i, 2], 2:3]
@@ -101,6 +118,8 @@ aligned_molecular_formula_annotator <- function(PARAM) {
     return(molecularFormulaFreqRank)
   }
   ##
+  ##############################################################################
+  ##
   call_mz_rt_freq_median_peak_property <- function(i) {
     x_h <- which(peak_property[i, 3:L_samples2] != 0)
     freq_h <- length(x_h)
@@ -113,9 +132,10 @@ aligned_molecular_formula_annotator <- function(PARAM) {
   }
   ##
   ##############################################################################
+  ##
   if (number_processing_threads == 1) {
     ##
-    UFA_logRecorder("Initiated matching peak IDs!")
+    IPA_logRecorder("Initiated matching peak IDs!")
     progressBARboundaries <- txtProgressBar(min = 0, max = L_samples, initial = 0, style = 3)
     #
     MF_Zcol <- do.call(rbind, lapply(seqSample, function(i) {
@@ -139,9 +159,9 @@ aligned_molecular_formula_annotator <- function(PARAM) {
     xZcol[u_peakid, 1] <- c(1, (xDiff + 1))
     xZcol[u_peakid, 2] <- c(xDiff, dim(MF_Zcol)[1])
     #
-    UFA_logRecorder("Completed matching peak IDs!")
+    IPA_logRecorder("Completed matching peak IDs!")
     ##
-    UFA_logRecorder("Initiated calculating median ranks!")
+    IPA_logRecorder("Initiated calculating median ranks!")
     progressBARboundaries <- txtProgressBar(min = 0, max = L_peaks, initial = 0, style = 3)
     #
     aligned_molecular_formula <- do.call(rbind, lapply(1:L_peaks, function(i) {
@@ -151,9 +171,9 @@ aligned_molecular_formula_annotator <- function(PARAM) {
     }))
     MF_Zcol <- NULL
     close(progressBARboundaries)
-    UFA_logRecorder("Completed calculating median ranks!")
+    IPA_logRecorder("Completed calculating median ranks!")
     ##
-    UFA_logRecorder("Initiated processing the peak property table!")
+    IPA_logRecorder("Initiated processing the peak property table!")
     progressBARboundaries <- txtProgressBar(min = 0, max = L_peaks, initial = 0, style = 3)
     IPA_Xcol <- do.call(rbind, lapply(1:L_peaks, function(i) {
       setTxtProgressBar(progressBARboundaries, i)
@@ -178,7 +198,7 @@ aligned_molecular_formula_annotator <- function(PARAM) {
     ##
     if (osType == "Linux") {
       ##
-      UFA_logRecorder("Initiated matching peak IDs!")
+      IPA_logRecorder("Initiated matching peak IDs!")
       MF_Zcol <- do.call(rbind, mclapply(seqSample, function(i) {
         call_MF_Zcol(i)
       }, mc.cores = number_processing_threads))
@@ -197,16 +217,16 @@ aligned_molecular_formula_annotator <- function(PARAM) {
       xZcol[u_peakid, 1] <- c(1, (xDiff + 1))
       xZcol[u_peakid, 2] <- c(xDiff, dim(MF_Zcol)[1])
       #
-      UFA_logRecorder("Completed matching peak IDs!")
+      IPA_logRecorder("Completed matching peak IDs!")
       ##
-      UFA_logRecorder("Initiated calculating median ranks!")
+      IPA_logRecorder("Initiated calculating median ranks!")
       aligned_molecular_formula <- do.call(rbind, mclapply(1:L_peaks, function(i) {
         call_calculating_median_ranks(i)
       }, mc.cores = number_processing_threads))
       MF_Zcol <- NULL
-      UFA_logRecorder("Completed calculating median ranks!")
+      IPA_logRecorder("Completed calculating median ranks!")
       ##
-      UFA_logRecorder("Initiated processing the peak property table!")
+      IPA_logRecorder("Initiated processing the peak property table!")
       ##
       IPA_Xcol <- do.call(rbind, mclapply(1:L_peaks, function(i) {
         c(peakXcol[i, 1:2], length(which(peakXcol[i, 3:L_samples2] > 0)))
@@ -226,7 +246,7 @@ aligned_molecular_formula_annotator <- function(PARAM) {
       clust <- makeCluster(number_processing_threads)
       registerDoParallel(clust)
       ##
-      UFA_logRecorder("Initiated matching peak IDs!")
+      IPA_logRecorder("Initiated matching peak IDs!")
       MF_Zcol <- foreach(i = seqSample, .combine = 'rbind', .verbose = FALSE) %dopar% {
         call_MF_Zcol(i)
       }
@@ -245,16 +265,16 @@ aligned_molecular_formula_annotator <- function(PARAM) {
       xZcol[u_peakid, 1] <- c(1, (xDiff + 1))
       xZcol[u_peakid, 2] <- c(xDiff, dim(MF_Zcol)[1])
       #
-      UFA_logRecorder("Completed matching peak IDs!")
+      IPA_logRecorder("Completed matching peak IDs!")
       ##
-      UFA_logRecorder("Initiated calculating median ranks!")
+      IPA_logRecorder("Initiated calculating median ranks!")
       aligned_molecular_formula <- foreach(i = 1:L_peaks, .combine = 'rbind', .verbose = FALSE) %dopar% {
         call_calculating_median_ranks(i)
       }
       MF_Zcol <- NULL
-      UFA_logRecorder("Completed calculating median ranks!")
+      IPA_logRecorder("Completed calculating median ranks!")
       ##
-      UFA_logRecorder("Initiated processing the peak property table!")
+      IPA_logRecorder("Initiated processing the peak property table!")
       ##
       IPA_Xcol <- foreach(i = 1:L_peaks, .combine = 'rbind', .verbose = FALSE) %dopar% {
         c(peakXcol[i, 1:2], length(which(peakXcol[i, 3:L_samples2] > 0)))
@@ -281,15 +301,15 @@ aligned_molecular_formula_annotator <- function(PARAM) {
   title_mat <- cbind("m/z", "RT", "IPA detection frequency", paste0(peak_property_name, " frequency"), paste0("median ", peak_property_name), title_mat)
   colnames(aligned_molecular_formula) <- title_mat
   rownames(aligned_molecular_formula) <- NULL
-  UFA_logRecorder("Completed processing of the peak property table!")
+  IPA_logRecorder("Completed processing of the peak property table!")
   output_path_aligned_table <- paste0(output_path, "/aligned_molecular_formula_table")
   if (!dir.exists(output_path_aligned_table)) {
     dir.create(output_path_aligned_table, recursive = TRUE)
   }
-  UFA_logRecorder("Initiated saving the aligned molecular formula annotated table!")
+  IPA_logRecorder("Initiated saving the aligned molecular formula annotated table!")
   save(aligned_molecular_formula, file = paste0(output_path_aligned_table, "/aligned_molecular_formula.Rdata"))
-  write.csv(aligned_molecular_formula, file = paste0(output_path_aligned_table, "/aligned_molecular_formula.csv"))
-  UFA_logRecorder("Stored annotated aligned table as `aligned_molecular_formula` in the `.Rdata` and `.csv` formats in the `aligned_molecular_formula_table` folder!")
-  UFA_logRecorder("Completed generating data for the aligned molecular formula annotated table!")
-  UFA_logRecorder(paste0(rep("", 100), collapse = "-"))
+  write.csv(aligned_molecular_formula, file = paste0(output_path_aligned_table, "/aligned_molecular_formula.csv"), row.names = FALSE)
+  IPA_logRecorder("Stored annotated aligned table as `aligned_molecular_formula` in the `.Rdata` and `.csv` formats in the `aligned_molecular_formula_table` folder!")
+  IPA_logRecorder("Completed generating data for the aligned molecular formula annotated table!")
+  IPA_logRecorder(paste0(rep("", 100), collapse = "-"))
 }
